pub fn parse_params<T: DeserializeOwned>(params: &Value) -> Result<T, RpcError>Expand description
Extract a typed parameter struct from the raw Value, producing an
InvalidParams RPC error on failure.
pub fn parse_params<T: DeserializeOwned>(params: &Value) -> Result<T, RpcError>Extract a typed parameter struct from the raw Value, producing an
InvalidParams RPC error on failure.